@@ -2,7 +2,8 @@
 
 #
 # dbcolrename.pm
-# Copyright (C) 1991-2018 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1991-2007 by John Heidemann <johnh@isi.edu>
+# $Id$
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -110,8 +111,8 @@ L<Fsdb>.
 ($VERSION) = 2.0;
 
 use strict;
-use Pod::Usage;
 use Carp;
+use Pod::Usage;
 
 use Fsdb::Filter;
 use Fsdb::IO::Reader;
@@ -122,7 +123,7 @@ use Fsdb::IO::Writer;
 
     $filter = new Fsdb::Filter::dbcolrename(@arguments);
 
-Create a new dbcolrename object, taking command-line arguments.
+Create a new dbcolrename object, taking command-line arugments.
 
 =cut
 
@@ -176,7 +177,7 @@ sub parse_options ($@) {
 	'log!' => \$self->{_logprog},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
 	) or pod2usage(2);
-    croak($self->{_prog} . ": dbcolrename requires an even number of arguments to do (old,new pairs)\n")
+    croak $self->{_prog} . ": dbcolrename requires an even number of arguments to do (old,new pairs)\n"
         if ( ($#argv + 1) % 2 != 0);
     while ($#argv >= 1) {
 	my($old) = shift @argv;
@@ -213,9 +214,9 @@ sub setup ($) {
 	my ($old) = $_;
 	my ($new) = $self->{_rename_map}{$old};
 	my $old_i = $self->{_in}->col_to_i($old);
-	croak($self->{_prog} . ": column `$old' is not in input stream.\n")
+	croak $self->{_prog} . ": column `$old' is not in input stream.\n"
 	    if (!defined($old_i));
-	croak($self->{_prog} . ": column `$new' already exists in the output stream.\n")
+	croak $self->{_prog} . ": column `$new' already exists in the output stream.\n"
 	    if (defined($cur_cols{$new}));
 	$new_cols[$old_i] = $new;
 	$cur_cols{$new} = $old_i;
@@ -246,7 +247,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1991-2018 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1991-2007 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
